==> zio-aws-ec2_2.13-5.17.127.1-sources.jar: zio/aws/ec2/model/TransitGatewayAttachmentPropagation.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class TransitGatewayAttachmentPropagation(
    transitGatewayRouteTableId: Option[String] = None,
    state: Option[zio.aws.ec2.model.TransitGatewayPropagationState] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.TransitGatewayAttachmentPropagation = {
    import TransitGatewayAttachmentPropagation.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.TransitGatewayAttachmentPropagation
      .builder()
      .optionallyWith(
        transitGatewayRouteTableId.map(value => value: java.lang.String)
      )(_.transitGatewayRouteTableId)
      .optionallyWith(state.map(value => value.unwrap))(_.state)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.TransitGatewayAttachmentPropagation.ReadOnly =
    zio.aws.ec2.model.TransitGatewayAttachmentPropagation.wrap(buildAwsValue())
}
object TransitGatewayAttachmentPropagation {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.TransitGatewayAttachmentPropagation
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.TransitGatewayAttachmentPropagation =
      zio.aws.ec2.model.TransitGatewayAttachmentPropagation(
        transitGatewayRouteTableId.map(value => value),
        state.map(value => value)
      )
    def transitGatewayRouteTableId: Option[String]
    def state: Option[zio.aws.ec2.model.TransitGatewayPropagationState]
    def getTransitGatewayRouteTableId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField(
        "transitGatewayRouteTableId",
        transitGatewayRouteTableId
      )
    def getState
        : ZIO[Any, AwsError, zio.aws.ec2.model.TransitGatewayPropagationState] =
      AwsError.unwrapOptionField("state", state)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.TransitGatewayAttachmentPropagation
  ) extends zio.aws.ec2.model.TransitGatewayAttachmentPropagation.ReadOnly {
    override val transitGatewayRouteTableId: Option[String] = scala
      .Option(impl.transitGatewayRouteTableId())
      .map(value => value: String)
    override val state
        : Option[zio.aws.ec2.model.TransitGatewayPropagationState] = scala
      .Option(impl.state())
      .map(value =>
        zio.aws.ec2.model.TransitGatewayPropagationState.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.TransitGatewayAttachmentPropagation
  ): zio.aws.ec2.model.TransitGatewayAttachmentPropagation.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-7.21.15.7-sources.jar: zio/aws/ec2/model/TransitGatewayAttachmentPropagation.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class TransitGatewayAttachmentPropagation(
    transitGatewayRouteTableId: Optional[String] = Optional.Absent,
    state: Optional[zio.aws.ec2.model.TransitGatewayPropagationState] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.TransitGatewayAttachmentPropagation = {
    import TransitGatewayAttachmentPropagation.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.TransitGatewayAttachmentPropagation
      .builder()
      .optionallyWith(
        transitGatewayRouteTableId.map(value => value: java.lang.String)
      )(_.transitGatewayRouteTableId)
      .optionallyWith(state.map(value => value.unwrap))(_.state)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.TransitGatewayAttachmentPropagation.ReadOnly =
    zio.aws.ec2.model.TransitGatewayAttachmentPropagation.wrap(buildAwsValue())
}
object TransitGatewayAttachmentPropagation {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.TransitGatewayAttachmentPropagation
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.TransitGatewayAttachmentPropagation =
      zio.aws.ec2.model.TransitGatewayAttachmentPropagation(
        transitGatewayRouteTableId.map(value => value),
        state.map(value => value)
      )
    def transitGatewayRouteTableId: Optional[String]
    def state: Optional[zio.aws.ec2.model.TransitGatewayPropagationState]
    def getTransitGatewayRouteTableId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField(
        "transitGatewayRouteTableId",
        transitGatewayRouteTableId
      )
    def getState
        : ZIO[Any, AwsError, zio.aws.ec2.model.TransitGatewayPropagationState] =
      AwsError.unwrapOptionField("state", state)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.TransitGatewayAttachmentPropagation
  ) extends zio.aws.ec2.model.TransitGatewayAttachmentPropagation.ReadOnly {
    override val transitGatewayRouteTableId: Optional[String] =
      zio.aws.core.internal
        .optionalFromNullable(impl.transitGatewayRouteTableId())
        .map(value => value: String)
    override val state
        : Optional[zio.aws.ec2.model.TransitGatewayPropagationState] =
      zio.aws.core.internal
        .optionalFromNullable(impl.state())
        .map(value =>
          zio.aws.ec2.model.TransitGatewayPropagationState.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.TransitGatewayAttachmentPropagation
  ): zio.aws.ec2.model.TransitGatewayAttachmentPropagation.ReadOnly =
    new Wrapper(impl)
}
